@@ -34,6 +34,7 @@ describe 'glance::api' do
       :image_cache_stall_time         => '<SERVICE DEFAULT>',
       :image_cache_max_size           => '<SERVICE DEFAULT>',
       :cache_prefetcher_interval      => '<SERVICE DEFAULT>',
+      :disk_formats                   => '<SERVICE DEFAULT>',
       :pipeline                       => 'keystone',
       :task_time_to_live              => '<SERVICE DEFAULT>',
       :task_executor                  => '<SERVICE DEFAULT>',
@@ -188,6 +189,11 @@ describe 'glance::api' do
           is_expected.to contain_glance_api_config('DEFAULT/key_file').with_value('<SERVICE DEFAULT>')
         end
 
+        it 'is_expected.to have no formats set' do
+          is_expected.to contain_glance_api_config('image_format/container_formats').with_value('<SERVICE DEFAULT>')
+          is_expected.to contain_glance_api_config('image_format/disk_formats').with_value('<SERVICE DEFAULT>')
+        end
+
         it 'passes purge to resource' do
           is_expected.to contain_resources('glance_api_config').with({
             :purge => false
@@ -289,6 +295,34 @@ describe 'glance::api' do
       end
     end
 
+    describe 'with formats options with strings' do
+      let :params do
+        default_params.merge({
+          :container_formats => 'ami,ari',
+          :disk_formats      => 'raw,iso',
+        })
+      end
+
+      context 'with disk_formats option' do
+        it { is_expected.to contain_glance_api_config('image_format/container_formats').with_value('ami,ari') }
+        it { is_expected.to contain_glance_api_config('image_format/disk_formats').with_value('raw,iso') }
+      end
+    end
+
+    describe 'with formats options with arrays' do
+      let :params do
+        default_params.merge({
+          :container_formats => ['ami', 'ari'],
+          :disk_formats      => ['raw', 'iso'],
+        })
+      end
+
+      context 'with disk_formats option' do
+        it { is_expected.to contain_glance_api_config('image_format/container_formats').with_value('ami,ari') }
+        it { is_expected.to contain_glance_api_config('image_format/disk_formats').with_value('raw,iso') }
+      end
+    end
+
     describe 'with enabled_backends and stores by default' do
       let :params do
         default_params
