@@ -5,7 +5,7 @@ describe 'glance::policy' do
   shared_examples_for 'glance policies' do
     let :params do
       {
-        :policy_path => '/etc/glance/policy.json',
+        :policy_path => '/etc/glance/policy.yaml',
         :policies    => {
           'context_is_admin' => {
             'key'   => 'context_is_admin',
@@ -17,14 +17,14 @@ describe 'glance::policy' do
 
     it 'set up the policies' do
       is_expected.to contain_openstacklib__policy__base('context_is_admin').with({
-        :key   => 'context_is_admin',
-        :value => 'foo:bar'
+        :key         => 'context_is_admin',
+        :value       => 'foo:bar',
+        :file_user   => 'root',
+        :file_group  => 'glance',
+        :file_format => 'yaml',
       })
       is_expected.to contain_oslo__policy('glance_api_config').with(
-        :policy_file => '/etc/glance/policy.json',
-      )
-      is_expected.to contain_oslo__policy('glance_registry_config').with(
-        :policy_file => '/etc/glance/policy.json',
+        :policy_file => '/etc/glance/policy.yaml',
       )
     end
   end
