@@ -41,9 +41,9 @@ describe 'glance::backend::multistore::cinder' do
         is_expected.to contain_glance_api_config('cinder/cinder_store_user_name').with_value('<SERVICE DEFAULT>')
         is_expected.to contain_glance_api_config('cinder/cinder_store_password').with_value('<SERVICE DEFAULT>').with_secret(true)
         is_expected.to contain_glance_api_config('cinder/cinder_os_region_name').with_value('RegionOne')
+        is_expected.to contain_glance_api_config('cinder/cinder_volume_type').with_value('<SERVICE DEFAULT>')
         is_expected.to contain_glance_api_config('cinder/cinder_enforce_multipath').with_value('<SERVICE DEFAULT>')
         is_expected.to contain_glance_api_config('cinder/cinder_use_multipath').with_value('<SERVICE DEFAULT>')
-        is_expected.to contain_glance_api_config('cinder/cinder_mount_point_base').with_value('<SERVICE DEFAULT>')
       end
       it 'configures glance-cache.conf' do
         is_expected.to_not contain_glance_cache_config('cinder/store_description')
@@ -57,9 +57,9 @@ describe 'glance::backend::multistore::cinder' do
         is_expected.to contain_glance_cache_config('cinder/cinder_store_user_name').with_value('<SERVICE DEFAULT>')
         is_expected.to contain_glance_cache_config('cinder/cinder_store_password').with_value('<SERVICE DEFAULT>').with_secret(true)
         is_expected.to contain_glance_cache_config('cinder/cinder_os_region_name').with_value('RegionOne')
+        is_expected.to contain_glance_cache_config('cinder/cinder_volume_type').with_value('<SERVICE DEFAULT>')
         is_expected.to contain_glance_cache_config('cinder/cinder_enforce_multipath').with_value('<SERVICE DEFAULT>')
         is_expected.to contain_glance_cache_config('cinder/cinder_use_multipath').with_value('<SERVICE DEFAULT>')
-        is_expected.to contain_glance_cache_config('cinder/cinder_mount_point_base').with_value('<SERVICE DEFAULT>')
       end
     end
 
@@ -77,9 +77,9 @@ describe 'glance::backend::multistore::cinder' do
           :cinder_store_user_name      => 'glance',
           :cinder_store_password       => 'glance',
           :cinder_os_region_name       => 'RegionTwo',
+          :cinder_volume_type          => 'glance-fast',
           :cinder_enforce_multipath    => true,
           :cinder_use_multipath        => true,
-          :cinder_mount_point_base     => '/var/lib/glance/mnt',
         }
       end
       it 'configures glance-api.conf' do
@@ -94,9 +94,9 @@ describe 'glance::backend::multistore::cinder' do
         is_expected.to contain_glance_api_config('cinder/cinder_store_user_name').with_value('glance')
         is_expected.to contain_glance_api_config('cinder/cinder_store_password').with_value('glance').with_secret(true)
         is_expected.to contain_glance_api_config('cinder/cinder_os_region_name').with_value('RegionTwo')
+        is_expected.to contain_glance_api_config('cinder/cinder_volume_type').with_value('glance-fast')
         is_expected.to contain_glance_api_config('cinder/cinder_enforce_multipath').with_value(true)
         is_expected.to contain_glance_api_config('cinder/cinder_use_multipath').with_value(true)
-        is_expected.to contain_glance_api_config('cinder/cinder_mount_point_base').with_value('/var/lib/glance/mnt')
       end
       it 'configures glance-cache.conf' do
         is_expected.to_not contain_glance_cache_config('cinder/store_description')
@@ -110,9 +110,9 @@ describe 'glance::backend::multistore::cinder' do
         is_expected.to contain_glance_cache_config('cinder/cinder_store_user_name').with_value('glance')
         is_expected.to contain_glance_cache_config('cinder/cinder_store_password').with_value('glance').with_secret(true)
         is_expected.to contain_glance_cache_config('cinder/cinder_os_region_name').with_value('RegionTwo')
+        is_expected.to contain_glance_cache_config('cinder/cinder_volume_type').with_value('glance-fast')
         is_expected.to contain_glance_cache_config('cinder/cinder_enforce_multipath').with_value(true)
         is_expected.to contain_glance_cache_config('cinder/cinder_use_multipath').with_value(true)
-        is_expected.to contain_glance_cache_config('cinder/cinder_mount_point_base').with_value('/var/lib/glance/mnt')
       end
     end
   end
